==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/model/MsImportFieldResponse.java <==
package com.xforceplus.seller.config.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.seller.config.client.model.MsImportField;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 用户自定义导入模板字段
 */
@ApiModel(description = "用户自定义导入模板字段")

@JsonInclude(NON_NULL)
public class MsImportFieldResponse {
  @JsonProperty("code")
  private Integer code = null;

  @JsonProperty("message")
  private String message = null;

  @JsonProperty("result")
  private List<MsImportField> result = new ArrayList<MsImportField>();

  @JsonIgnore
  public MsImportFieldResponse code(Integer code) {
    this.code = code;
    return this;
  }

   /**
   * 代码
   * @return code
  **/
  @ApiModelProperty(value = "代码")
  public Integer getCode() {
    return code;
  }

  public void setCode(Integer code) {
    this.code = code;
  }

  @JsonIgnore
  public MsImportFieldResponse message(String message) {
    this.message = message;
    return this;
  }

   /**
   * 消息
   * @return message
  **/
  @ApiModelProperty(value = "消息")
  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @JsonIgnore
  public MsImportFieldResponse result(List<MsImportField> result) {
    this.result = result;
    return this;
  }

  public MsImportFieldResponse addResultItem(MsImportField resultItem) {
    this.result.add(resultItem);
    return this;
  }

   /**
   * Get result
   * @return result
  **/
  @ApiModelProperty(value = "")
  public List<MsImportField> getResult() {
    return result;
  }

  public void setResult(List<MsImportField> result) {
    this.result = result;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsImportFieldResponse importFieldResponse = (MsImportFieldResponse) o;
    return Objects.equals(this.code, importFieldResponse.code) &&
        Objects.equals(this.message, importFieldResponse.message) &&
        Objects.equals(this.result, importFieldResponse.result);
  }

  @Override
  public int hashCode() {
    return Objects.hash(code, message, result);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsImportFieldResponse {\n");
    
    sb.append("    code: ").append(toIndentedString(code)).append("\n");
    sb.append("    message: ").append(toIndentedString(message)).append("\n");
    sb.append("    result: ").append(toIndentedString(result)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> seller-config-client-api-4.1.30-20250926.030812-1-sources.jar: com/xforceplus/seller/config/client/model/MsImportFieldResponse.java <==
package com.xforceplus.seller.config.client.model;

import java.io.Serializable;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.seller.config.client.model.MsImportField;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 用户自定义导入模板字段
 */
@ApiModel(description = "用户自定义导入模板字段")

@JsonInclude(NON_NULL)
public class MsImportFieldResponse implements Serializable {
  @JsonProperty("code")
  private Integer code = null;

  @JsonProperty("message")
  private String message = null;

  @JsonProperty("result")
  private List<MsImportField> result = new ArrayList<MsImportField>();

  @JsonIgnore
  public MsImportFieldResponse code(Integer code) {
    this.code = code;
    return this;
  }

   /**
   * 代码
   * @return code
  **/
  @ApiModelProperty(value = "代码")
  public Integer getCode() {
    return code;
  }

  public void setCode(Integer code) {
    this.code = code;
  }

  @JsonIgnore
  public MsImportFieldResponse message(String message) {
    this.message = message;
    return this;
  }

   /**
   * 消息
   * @return message
  **/
  @ApiModelProperty(value = "消息")
  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @JsonIgnore
  public MsImportFieldResponse result(List<MsImportField> result) {
    this.result = result;
    return this;
  }

  public MsImportFieldResponse addResultItem(MsImportField resultItem) {
    this.result.add(resultItem);
    return this;
  }

   /**
   * Get result
   * @return result
  **/
  @ApiModelProperty(value = "")
  public List<MsImportField> getResult() {
    return result;
  }

  public void setResult(List<MsImportField> result) {
    this.result = result;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsImportFieldResponse importFieldResponse = (MsImportFieldResponse) o;
    return Objects.equals(this.code, importFieldResponse.code) &&
        Objects.equals(this.message, importFieldResponse.message) &&
        Objects.equals(this.result, importFieldResponse.result);
  }

  @Override
  public int hashCode() {
    return Objects.hash(code, message, result);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsImportFieldResponse {\n");
    
    sb.append("    code: ").append(toIndentedString(code)).append("\n");
    sb.append("    message: ").append(toIndentedString(message)).append("\n");
    sb.append("    result: ").append(toIndentedString(result)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
